/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.jbi.descriptor;

import javax.xml.namespace.QName;

import org.objectweb.petals.jbi.descriptor.util.XMLUtil;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * @author Christophe HAMERLING (chamerling) - eBM WebSourcing
 *
 */
@SuppressWarnings("PMD.UnnecessaryConstructor")
public abstract class ServiceUnitExtensibleElement extends ExtensibleJbiElement {
    /**
     * Endpoint name to be provided.
     */
    protected String endpointName;

    /**
     * Qualified interface name.
     */
    protected QName interfaceName;

    /**
     * Service name to be provided.
     */
    protected QName serviceName;

    /**
     * Creates a new instance of {@link ServiceUnitExtensibleElement}
     *
     */
    public ServiceUnitExtensibleElement() {
        super();
    }

    /**
     * Generate a XML representation of the consumes or provides descriptor node
     *
     * @return the XML representation
     */
    @Override
    public final Node getNode(final Document jbiDescriptorDocument) {

        final Element nodeElement = jbiDescriptorDocument
                .createElementNS(XMLUtil.JBI_NAMESPACE, this.getNodeName());

        final Element interfaceElement = jbiDescriptorDocument.createElementNS(
                XMLUtil.JBI_NAMESPACE, "interface-name");
        XMLUtil.setQNameValue(this.interfaceName, jbiDescriptorDocument, interfaceElement);
        nodeElement.appendChild(interfaceElement);

        final Element serviceElement = jbiDescriptorDocument.createElementNS(
                XMLUtil.JBI_NAMESPACE, "service-name");
        XMLUtil.setQNameValue(this.serviceName, jbiDescriptorDocument, serviceElement);
        nodeElement.appendChild(serviceElement);

        final Element endpointElement = jbiDescriptorDocument.createElementNS(
                XMLUtil.JBI_NAMESPACE, "endpoint-name");
        endpointElement.setTextContent(this.endpointName);
        nodeElement.appendChild(endpointElement);
        
        nodeElement.appendChild(super.getNode(jbiDescriptorDocument));

        return nodeElement;
    }

    /**
     * Method used by {@link #toXmlText()} to get the name of the XML root node of this object.
     */
    protected abstract String getNodeName();

    /**
     * @return the endpointName
     */
    public final String getEndpointName() {
        return this.endpointName;
    }

    /**
     * @param endpointName
     *            the endpointName to set
     */
    public final void setEndpointName(final String endpointName) {
        this.endpointName = endpointName;
    }

    /**
     * @return the interfaceName
     */
    public final QName getInterfaceName() {
        return this.interfaceName;
    }

    /**
     * @param interfaceName
     *            the interfaceName to set
     */
    public final void setInterfaceName(final QName interfaceName) {
        this.interfaceName = interfaceName;
    }

    /**
     * @return the serviceName
     */
    public final QName getServiceName() {
        return this.serviceName;
    }

    /**
     * @param serviceName
     *            the serviceName to set
     */
    public final void setServiceName(final QName serviceName) {
        this.serviceName = serviceName;
    }
}
