/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: SharedLibraryList.java 477 2006-05-29 15:18:07Z ddesjardins $
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.jbi.descriptor;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.objectweb.petals.jbi.descriptor.util.XMLUtil;
import org.w3c.dom.Attr;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * Shared library list production is used together with a parametrized
 * {@link List} to provide the pair info of shared library listing used by the
 * component.
 *
 * @version $Rev: 477 $ $Date: 2006-05-29 15:18:07Z $
 * @since Petals 1.0
 * @author <a href="mailto:rmarins@fossilec.com">Rafael Marins</a>
 */
public class SharedLibraryList {

    /**
     * Shared library name.
     */
    private String name;

    /**
     * Optional shared library version.
     */
    private String version;

    /**
     * Default constructor.
     */
    SharedLibraryList() {
        super();
    }

    @Override
    public boolean equals(final Object other) {
        boolean bRet;
        if (other instanceof SharedLibraryList) {
            final SharedLibraryList castOther = (SharedLibraryList) other;
            bRet = new EqualsBuilder().append(this.name, castOther.name).append(this.version,
                    castOther.version).isEquals();
        } else {
            bRet = false;
        }

        return bRet;
    }

    @Override
    public int hashCode() {
        return new HashCodeBuilder().append(this.name).append(this.version).toHashCode();
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this).append("name", this.name).append("version",
                this.version).toString();
    }

    /**
     * Generate a XML representation of the service assembly descriptor node
     * @return the XML representation
     */
    public final Node getNode(final Document jbiDescriptorDocument) {

        final Element sharedLibraryElement = jbiDescriptorDocument
                            .createElementNS(XMLUtil.JBI_NAMESPACE, "shared-library");

        if (this.version != null
                && !"".equals(this.version)) {
            final Attr versionAttribute = jbiDescriptorDocument
                    .createAttributeNS(XMLUtil.JBI_NAMESPACE, "version");
            versionAttribute.setValue(this.version);
            sharedLibraryElement.setAttributeNode(versionAttribute);
        }

        sharedLibraryElement.setTextContent(this.name);

        return sharedLibraryElement;
    }

    //
    // Getters and Setters
    //

    /**
     * Returns the shared library name.
     *
     * @return <code>String</code> the shared library name.
     */
    public final String getName() {
        return this.name;
    }

    /**
     * Returns the shared library version. May be <code>null</code> since it's
     * optional.
     *
     * @return <code>String</code> optional shared library version.
     */
    public final String getVersion() {
        return this.version;
    }

    /**
     * Set shared library name.
     *
     * @param name
     *            <code>String</code> shared library name.
     */
    public final void setName(final String name) {
        this.name = name;
    }

    /**
     * Set the optional shared library version.
     *
     * @param version
     *            <code>String</code> shared library version.
     */
    public final void  setVersion(final String version) {
        this.version = version;
    }

}
